package net.stocks;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.StringTokenizer;
import java.util.Vector;

public class Quote {
    private String symbol;
    private String price;
    private String date;
    private String time;
    private String change;
    private String open;
    private String bid;
    private String ask;
    private String volume;

    public Quote(String s) {
        // assume that the quote is of the form
        // symbol	price	date	time  (20 min. Delay)	  change	  open	  bid	  ask	  volume
        // "AAPL",55.31,"11/3/2004","4:00pm",+1.81,54.44,56.11,53.99,21504764
        StringTokenizer st = new StringTokenizer(s, ",");
        symbol= st.nextToken();
        price = st.nextToken();
        date  = st.nextToken();
        time  = st.nextToken();
        change = st.nextToken();
        open   = st.nextToken();
        bid    = st.nextToken();
        ask    = st.nextToken();
        volume = st.nextToken();
    }
    public static void print(Object o[]){
        for (int i=0; i < o.length; i++)
            System.out.println(o[i]);
    }
    public String toString() {
        return symbol+" "+price+" "+ volume;
    }

    public static void main(String args[]) {
        testQuoteSystem();
    }

    private static void testQuoteSystem() {
        Vector s = new Vector();
        s.addElement("aapl");
        s.addElement("xlnx");
        s.addElement("altr");
        s.addElement("mot");
        s.addElement("cy");
        s.addElement("crus");
        s.addElement("sfa");
        s.addElement("adbe");
        s.addElement("msft");
        s.addElement("sunw");
        String urlString = makeQuoteURLString(s);
        //System.out.println(urlString);
        Vector url = getUrl(urlString);
        //printVector(url);
        print(getQuotes(url));
    }

    public static Quote[] getQuotes(Vector v) {
        Quote qa [] = new Quote[v.size()];
        for (int i = 0; i < qa.length; i++) {
            String s = v.elementAt(i).toString();
            if (s.indexOf(",") == -1) continue;
            qa[i] = new Quote(s);
        }
        return qa;
    }

    public static void printVector(Vector v) {
        for (int i = 0; i < v.size(); i++) {
            System.out.println(v.elementAt(i));
        }
    }

    public static Vector getUrl(String _URLString) {
        Vector contents = new Vector();
        BufferedReader in = null;
        try {
            URL URLString = new URL(_URLString);
            InputStream is = URLString.openStream();
            in = new BufferedReader(new
                    InputStreamReader(is));
            String line;
            contents.addElement("Copyright 1999 by Doug Lyon http://www.docjava.com");
            contents.addElement("symbol\tprice\tdate\ttime" +
                    "  (20 min. Delay)\t  change\t  open\t  bid\t  ask\t  volume");
            while (null != (line = in.readLine()))
                contents.addElement(line);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (in != null) in.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return contents;
    }

    public static String makeQuoteURLString(Vector symbols) {
        String symbolsString = "";
        for (int i = 0; i < symbols.size(); i++) {
            String symbol = (String) symbols.elementAt(i);
            symbolsString += ((i != 0) ? "," : "") + symbol.toUpperCase();
        }
        return
                "http://216.109.124.128/download/javasoft.beans?SYMBOLS=" +
                symbolsString +
                "&format=sl";
    }

    public String getSymbol() {
        return symbol;
    }

    public void setSymbol(String symbol) {
        this.symbol = symbol;
    }

    public String getPrice() {
        return price;
    }

    public void setPrice(String price) {
        this.price = price;
    }

    public String getDate() {
        return date;
    }

    public void setDate(String date) {
        this.date = date;
    }

    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public String getChange() {
        return change;
    }

    public void setChange(String change) {
        this.change = change;
    }

    public String getOpen() {
        return open;
    }

    public void setOpen(String open) {
        this.open = open;
    }

    public String getBid() {
        return bid;
    }

    public void setBid(String bid) {
        this.bid = bid;
    }

    public String getAsk() {
        return ask;
    }

    public void setAsk(String ask) {
        this.ask = ask;
    }

    public String getVolume() {
        return volume;
    }

    public void setVolume(String volume) {
        this.volume = volume;
    }
}
